from .auth import GetToken, LojaPertencentesPrograma,\
    CadastrarConsumidor, AtualizarConsumidor, ConsultaConsumidor, ConsultaConsumidor,\
    RetornaDadosCliente,ResgataPremio,PontuaConsumidor,ListaProdutos
